MINOR: log: Add new "error-log-format" option

This option can be used to define a specific log format that will be
used in case of error, timeout, connection failure on a frontend... It
will be used for any log line concerned by the log-separate-errors
option. It will also replace the format of specific error messages
decribed in section 8.2.6.
If no "error-log-format" is defined, the legacy error messages are still
emitted and the other error logs keep using the regular log-format.
diff --git a/src/session.c b/src/session.c
index 92d03ea..a11475e 100644
--- a/src/session.c
+++ b/src/session.c
@@ -357,8 +357,8 @@
 				conn->err_code = CO_ER_SSL_TIMEOUT;
 		}
 
-		if (sess->fe->options & PR_O_ERR_LOGFMT) {
-			/* Display a log line following the configured log-format. */
+		if(!LIST_ISEMPTY(&sess->fe->logformat_error)) {
+			/* Display a log line following the configured error-log-format. */
 			sess_log(sess);
 		}
 		else {